summaryrefslogtreecommitdiff
path: root/fml/lib/FML/Process
diff options
context:
space:
mode:
authorfukachan <fukachan>2003-11-30 09:59:17 +0000
committerfukachan <fukachan>2003-11-30 09:59:17 +0000
commitba63f5f3b7154c090f72b898ecf48255ff48b874 (patch)
tree5bc92ce58582d5f98911bd15a9adb7f002fe005d /fml/lib/FML/Process
parent4934a4bd50caf85890f30cfcc08734bc159f600f (diff)
downloadfml8-ba63f5f3b7154c090f72b898ecf48255ff48b874.tar.gz
fml8-ba63f5f3b7154c090f72b898ecf48255ff48b874.tar.bz2
fml8-ba63f5f3b7154c090f72b898ecf48255ff48b874.zip
system_accounts -> system_special_accounts.
XXX xxx_restrictions supports "reject_system_accounts" for backward XXX compatiblity.
Diffstat (limited to 'fml/lib/FML/Process')
-rw-r--r--fml/lib/FML/Process/Command.pm8
-rw-r--r--fml/lib/FML/Process/Distribute.pm6
2 files changed, 7 insertions, 7 deletions
diff --git a/fml/lib/FML/Process/Distribute.pm b/fml/lib/FML/Process/Distribute.pm
index 3a1d7295..47fc84ae 100644
--- a/fml/lib/FML/Process/Distribute.pm
+++ b/fml/lib/FML/Process/Distribute.pm
@@ -3,7 +3,7 @@
# Copyright (C) 2000,2001,2002,2003 Ken'ichi Fukamachi
# All rights reserved.
#
-# $FML: Distribute.pm,v 1.128 2003/10/15 01:03:33 fukachan Exp $
+# $FML: Distribute.pm,v 1.129 2003/11/29 10:24:28 fukachan Exp $
#
package FML::Process::Distribute;
@@ -221,9 +221,9 @@ sub run
$curproc->log("deny article submission");
my $rule = $pcb->get("check_restrictions", "deny_reason");
- if ($rule eq 'reject_system_accounts') {
+ if ($rule eq 'reject_system_special_accounts') {
my $r = "deny request from a system account";
- $curproc->reply_message_nl("error.system_accounts",
+ $curproc->reply_message_nl("error.system_special_accounts",
$r, $msg_args);
}
elsif ($rule eq 'permit_member_maps') {
diff --git a/fml/lib/FML/Process/Command.pm b/fml/lib/FML/Process/Command.pm
index 55633cd7..84da87e5 100644
--- a/fml/lib/FML/Process/Command.pm
+++ b/fml/lib/FML/Process/Command.pm
@@ -3,7 +3,7 @@
# Copyright (C) 2000,2001,2002,2003 Ken'ichi Fukamachi
# All rights reserved.
#
-# $FML: Command.pm,v 1.90 2003/10/17 14:00:51 fukachan Exp $
+# $FML: Command.pm,v 1.91 2003/11/29 10:24:27 fukachan Exp $
#
package FML::Process::Command;
@@ -201,13 +201,13 @@ sub run
# XXX reject command use irrespective of requests from admins/users.
# XXX rejection of admin use occurs in _evaluate_command_lines()
# XXX not here.
# XXX possible cases are from "system_accounts" or from a not member.
else {
# check the error reason by permit_command().
my $reason = $pcb->get("check_restrictions", "deny_reason");
- if (defined($reason) && ($reason eq 'reject_system_accounts')) {
+ if (defined($reason) && ($reason eq 'reject_system_special_accounts')) {
my $s = "deny request from system accounts";
- $curproc->reply_message_nl("error.system_accounts", $s);
+ $curproc->reply_message_nl("error.system_special_accounts", $s);
}
else {
$curproc->reply_message_nl("error.not_member",
@@ -201,13 +201,13 @@ sub run
# XXX rejection of admin use occurs in _evaluate_command_lines()
# XXX not here.
- # XXX possible cases are from "system_accounts" or from a not member.
+ # XXX possible cases are from "system_special_accounts" or from a not member.
else {
# check the error reason by permit_command().